

Setting up your environment
===========================

First install the dependencies (you need a network connection for this step)::

  $ git checkout https://github.com/bast/cicero
  $ cd cicero

Now install https://flit.readthedocs.io/ from ``requirements.txt``.

Then install the package and start the server::

  $ flit install --symlink
  $ cicero

  * Running on http://127.0.0.1:5000/ (Press CTRL+C to quit)
